import struct
import logging

from parquet_tools.gen_py.parquet.ttypes import FileMetaData
from thrift.protocol import TCompactProtocol
from thrift.transport import TTransport

logger = logging.getLogger("parquet")


def get_filemetadata(path: str) -> FileMetaData:
    '''get file metadata using filepath'''
    with open(path, 'rb') as fo:
        return _read_footer(fo)


def _read_footer(file_obj) -> FileMetaData:
    footer_size = _get_footer_size(file_obj)
    file_obj.seek(-(8 + footer_size), 2)

    bytes_data = file_obj.read(footer_size)
    transportIn = TTransport.TMemoryBuffer(bytes_data)
    protocolIn = TCompactProtocol.TCompactProtocol(transportIn)
    fmd = FileMetaData()
    fmd.read(protocolIn)
    return fmd


def _get_footer_size(file_obj) -> int:
    file_obj.seek(-8, 2)
    tup = struct.unpack(b"<i", file_obj.read(4))
    return tup[0]



import argparse
from parquet_tools.commands import show, csv, inspect


def main() -> None:
    parser = argparse.ArgumentParser(
        prog='parquet-tools',
        description='parquet CLI tools'
    )
    subparsers = parser.add_subparsers()
    show.configure_parser(subparsers.add_parser(
        'show',
        help='Show human readable format. see `show -h`',
        description='Show parquet file content with human readability.'))
    csv.configure_parser(subparsers.add_parser(
        'csv',
        help='Cat csv style. see `csv -h`',
        description='Cat parquet as csv style.'))
    inspect.configure_parser(subparsers.add_parser(
        'inspect',
        help='Inspect parquet file. see `inspect -h`',
        description='Inspect parquet file.'))

    args = parser.parse_args()
    if hasattr(args, 'handler'):
        args.handler(args)
    else:
        parser.print_help()


if __name__ == '__main__':
    main()
